camelot.camelot.view.controls.formview.FormView

Package camelot :: Package camelot :: Package view :: Package controls :: Module formview :: Class FormView |
[hide private]
[frames] | no frames]

# Class FormView

source code

Instance Methods | [hide private]
__init__(self, title, admin, model, index) | source code
dataChanged(self, index_from, index_to) | source code
handleGetColumnsAndForm(self, columns, form) | source code
setColumnsFormAndDelegate(self, columns, form, delegate) Create value and label widgets | source code
getEntity(self) | source code
setActions(self, actions) | source code
viewFirst(self) select model's first row | source code
viewLast(self) select model's last row | source code
viewNext(self) select model's next row | source code
viewPrevious(self) select model's previous row | source code
validateClose(self) | source code
closeEvent(self, event) | source code
toHtml(self) generates html of the form | source code
__del__(self) deletes formview object | source code

Method Details | [hide private]

### toHtml(self) | source code
generates html of the form Decorators: `@model_function`